#
# spec file for package graphviz-smyrna
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define mname graphviz

Name:           graphviz-smyrna
Version:        2.38.0
Release:        4.17
Summary:        Glut based graph viewer
License:        EPL-1.0
Group:          Productivity/Graphics/Visualization/Graph
Url:            http://www.graphviz.org/
Source:         http://graphviz.org/pub/graphviz/stable/SOURCES/graphviz-%{version}.tar.gz
Source2:        graphviz-rpmlintrc
Patch2:         graphviz-fix-pkgIndex.patch
#PATCH-FIX-UPSTREAM There are too many type-punnings in the vmalloc sources
Patch3:         graphviz-no_strict_aliasing.patch
Patch4:         graphviz-array_overflow.patch
#PATCH-FIX-UPSTREAM add flags to also link against libGLU and libGL
Patch10:        graphviz-smyrna-link_against_glu.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  bison
BuildRequires:  fdupes
BuildRequires:  flex
BuildRequires:  freeglut-devel
BuildRequires:  freetype2-devel >= 2
BuildRequires:  gcc-c++
BuildRequires:  libXaw-devel
BuildRequires:  libexpat-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libpng-devel
BuildRequires:  libqt4-devel
BuildRequires:  libstdc++-devel
BuildRequires:  libtool
BuildRequires:  zlib-devel
%if 0%suse_version > 1220
BuildRequires:  freeglut-devel
BuildRequires:  glu-devel
BuildRequires:  gtkglext-devel
BuildRequires:  gts-devel
BuildRequires:  libglade2-devel
%endif
BuildRequires:  pkgconfig(fontconfig)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(ice)
BuildRequires:  pkgconfig(sm)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xext)
Requires(pre):  /bin/cat
Requires(pre):  /bin/rm
Recommends:     graphviz = %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
This is the graph editor included with graphviz, packaged
separately to avoid cycles in the build of the graphviz
package.

%prep
%setup -q -n %{mname}-%{version}
%patch2
%patch3
%patch10
%patch4
rm -f contrib/gprof2dot.awk

# Fix path in generated man pages
sed -e 's$@LIB_DIR@$%{_libdir}$g' tclpkg/gv/gv_doc_langs.tcl >tclpkg/gv/gv_doc_langs.tcl.new && mv tclpkg/gv/gv_doc_langs.tcl.new tclpkg/gv/gv_doc_langs.tcl

%build
autoreconf -fi
WARN_FLAGS="-W -Wall -Wno-unused-parameter -Wno-unknown-pragmas -Wstrict-prototypes -Wpointer-arith"
CFLAGS="%{optflags} $WARN_FLAGS"
%ifarch %ix86 x86_64
CFLAGS="$CFLAGS -ffast-math"
%endif

export CFLAGS="$CFLAGS"
export CPPFLAGS="%{optflags}"
%configure \
      --with-x \
      --with-mylibgd \
      --disable-static \
      --enable-ltdl-install=no \
      --with-ipsepcola \
      --without-ming \
      --disable-io \
      --disable-silent-rules \
      --with-mylibgd=no \
      --with-libgd=no \
      --with-smyrna=yes 
make %{?_smp_mflags} DESTDIR=%{buildroot}

%install
make install \
	DESTDIR=%{buildroot} \
	docdir=%{buildroot}%{_docdir}/%{mname} \
	pkgconfigdir=%{_libdir}/pkgconfig

find %{buildroot} -type f -name "*.la" -print0 | xargs -0 rm -f

mkdir -p %{buildroot}/%{_docdir}
mkdir -p %{buildroot}%{_datadir}/%{mname}

rm -f %{buildroot}/%{_libdir}/%{mname}/pkgIndex.tcl

cp -a %{buildroot}%{_datadir}/%{mname}/doc __doc
rm -rf %{buildroot}%{_datadir}/%{mname}/doc

rm -rf %{buildroot}%{_libdir}

mv %{buildroot}/%{_mandir}/man1/smyrna.1 /tmp/smyrna.1
rm -f %{buildroot}/%{_mandir}/man1/*
rm -rf %{buildroot}/%{_mandir}/man[37]
mv /tmp/smyrna.1 %{buildroot}/%{_mandir}/man1/smyrna.1

mv %{buildroot}/%{_bindir}/smyrna /tmp/smyrna
rm -f %{buildroot}/%{_bindir}/*
mv /tmp/smyrna %{buildroot}/%{_bindir}/smyrna

rm -rf %{buildroot}%{_datadir}/%{mname}/graphs
rm -rf %{buildroot}%{_datadir}/%{mname}/examples
rm -rf %{buildroot}%{_datadir}/%{mname}/gvedit
rm -rf %{buildroot}%{_datadir}/%{mname}/gvpr
rm -rf %{buildroot}%{_datadir}/%{mname}/lefty
rm -rf %{buildroot}%{_includedir}/%{mname}

%files
%defattr(-,root,root)
%doc COPYING
%attr(755,root,root) %{_bindir}/smyrna
%dir %{_datadir}/%{mname}
%{_datadir}/%{mname}/smyrna
%doc %{_mandir}/man1/*.1*

%changelog
* Fri Jun 19 2015 schwab@suse.de
- Fix build on aarch64
* Thu Jul 17 2014 pth@suse.de
- Change License to EPL-1.0.
* Fri May 23 2014 pth@suse.de
- Fix URL to point to the new location of the sources.
* Fri May 23 2014 pth@suse.de
- Update to 2.38.0. Changes since 1.35.0:
  - Resolve bugs: 2409, 2413, 2417, 2420, 2422, 2423, 2425
  - Enable packing for dot
  - Allow scaling to work for all non-dot layouts
  - Add overline text characteristic.
  - Fix bugs in gvpr and gv.cpp so edges can be created in subgraphs.
  - Add edgepaint program for coloring edges to make them easier to
    tell apart.
  - Modify neato to avoid unnecessary translations of output. This
    allows positions given on input to remain the same on output.
  - Fix swig java package to work and support gv.renderresult.
  - Fix test for the absence of layout (old test relied on statically
    allocated Agraphinfo_t).
  - HTML-like tables and cells can now specify which borders should be drawn.
  - The fixedsize attribute now takes the value "shape" which allows
    labels much larger than the node shape.
- Remove graphviz-fix-includes.patch as the fix has been done
  upstream.
- Add graphviz-array_overflow.patch to fix an off-by-one error.
* Tue Feb  4 2014 pth@suse.de
- Update to 2.36,0.
- Change license to EPL-1.0. Remove contrib/gprof2dot.awk as it
  contains a non-working uri.
* Thu Jan  2 2014 mrdocs@opensuse.org
- drop BuildRequires:gtkglarea2-devel its not in Factory
* Thu Oct 24 2013 pth@suse.de
- Split off smyrna into its own package and spec file to eliminate
  the dependency cycle for the graphviz package.
- Add libGLU and libGL as libraries to link to which was missing.
